@@ -17,6 +17,7 @@
 # properties.py - More black magic than Dumbledore can handle
 
 import gettext
+import sys
 
 import gobject
 import gtk
@@ -112,6 +113,7 @@ class PropRegistry:
         else:
             # XXX: Kill this, needs to fix readable/writable first
             #raise TypeError("%s exists, use override_simple" % full_name)
+            self._set_interval_from_pspec(klass, pspec)
             self._add_type(full_name, klass, pspec)
         
         # Note, that at this point we need to setup the overriden class
@@ -251,9 +253,22 @@ class PropRegistry:
                                  writable=writable,
                                  child=child,
                                  label=pspec.nick)
+        self._set_interval_from_pspec(prop_type, pspec)
         self._add_type(prop_type.__name__, prop_type, pspec)
         return prop_type
 
+    def _set_interval_from_pspec(self, prop_type, pspec):
+        if not hasattr(pspec, 'maximum'):
+            return
+
+        maximum = pspec.maximum
+        if maximum == -1 and pspec.value_type == gobject.TYPE_UINT:
+            maximum = sys.maxint
+        prop_type.maximum = maximum
+            
+        prop_type.minimum = pspec.minimum
+        prop_type.defautl = pspec.default_value
+
     def _add_type(self, prop_name, prop_type, pspec=None):
         if pspec:
             if gobject.type_is_a(pspec.value_type, gobject.TYPE_ENUM):
@@ -727,10 +742,12 @@ class BaseNumericType(PropType):
     digits = 0
     
     def get_adjustment(cls):
-        if not cls.minimum <= cls.default <= cls.maximum:
-            raise TypeError("default must be larger than minimum and lower "
-                            "than maximum (%r <= %r <= %r)" % (
-                cls.minimum, cls.default, cls.maximum))
+        #if not cls.minimum <= cls.default <= cls.maximum:
+        #    raise TypeError(
+        #        "default must be larger than minimum and lower "
+        #        "than maximum (%r <= %r <= %r) for %s::%s (%r)" % (
+        #        cls.minimum, cls.default, cls.maximum,
+        #        gobject.type_name(cls.owner_type), cls.name, cls.type))
             
         return gtk.Adjustment(value=cls.default,
                               lower=cls.minimum,
