@@ -32,10 +32,11 @@ def create_pixbuf(generic_name, palette_name, library_name, resource_path):
         else:
             path = environ.find_pixmap(filename)
 
-        try:
-            pixbuf = gtk.gdk.pixbuf_new_from_file(path)
-        except gobject.GError:
-            pass
+        if path is not None:
+            try:
+                pixbuf = gtk.gdk.pixbuf_new_from_file(path)
+            except gobject.GError:
+                pass
 
     # If we cannot find the icon and it's going to be shown in the palette
     # Print a warning and create an icon of a missing image instead
@@ -230,8 +231,8 @@ class WidgetAdaptor(object, BaseWidgetAdaptor):
         And what we consider default is the value assigned to an
         object immediatelly after it's called gobject.new.
         parent_name is used for packing properties
-        @param prop a property
-        @param parent_type parent gtype
+        @param prop: a property
+        @param parent_type: parent gtype
         """
         if not prop.child:
             if not self.default:
